@@ -1,12 +1,15 @@
 import os
+import os.path as osp
 import re
 import shutil
 from datetime import datetime, timedelta
 from glob import glob
 
 from loguru import logger
+from omegaconf import OmegaConf
 
 from jexp.utils import latest_time
+from jexp.wandb_clean import get_run_from_url
 
 
 def extract_all_exp(folder: str = "outputs"):
@@ -46,8 +49,8 @@ def clear_empty(folder: str = "outputs"):
             shutil.rmtree(str(cur_path), ignore_errors=True)
 
 
-def filter_hyd_short(folder: str = "outputs", delete=True):
-    survive = []
+def filter_hyd_stale(folder: str = "outputs"):
+    to_delete = []
     for run_f in extract_all_exp(folder):
         create_time = time_from_folder(run_f)
         end_time = latest_time(run_f)
@@ -57,9 +60,36 @@ def filter_hyd_short(folder: str = "outputs", delete=True):
         time_thred = [[0, 10], [7, 60], [3, 180], [1, 600]]
         for thr_d, thr_s in time_thred:
             if run2now > timedelta(days=thr_d) and duration < timedelta(seconds=thr_s):
-                logger.info(f"SHORT: {run_f}")
-                if delete:
-                    shutil.rmtree(run_f, ignore_errors=True)
+                wandb_run = run_from_meta(run_f)
+                if wandb_run is not None:
+                    logger.info(f"SHORT: {run_f}\t {wandb_run.url}")
+                else:
+                    logger.info(f"SHORT: {run_f}")
+                to_delete.append(run_f)
                 break
-        survive.append(run_f)
-    return survive
+    return to_delete
+
+
+def run_from_meta(run_f: str):
+    meta_f = osp.join(run_f, "meta.yaml")
+    if osp.exists(meta_f):
+        conf = OmegaConf.load(meta_f)
+        if "WEIGHT_URL" in conf:
+            run = get_run_from_url(conf["WEIGHT_URL"])
+            if run is not None:
+                return run
+    return None
+
+
+def delete_run_from_folder(run_f: str):
+    run = run_from_meta(run_f)
+    if run is not None:
+        run.delete()
+
+
+def filter_hyd_wandb(folder: str = "outputs"):
+    to_delete = []
+    for run_f in extract_all_exp(folder):
+        if run_from_meta(run_f) is None:
+            to_delete.append(run_f)
+    return to_delete
